==> vuejs-2.0.10.tgz: package/src/htmls/directives/screen-handle/index.js <==
import Vue from 'vue';
import ScreenHandleDirective from '@/directives/screen-handle';

Vue.config.productionTip = false;

/* eslint-disable no-new */
new Vue({
    el: '#app',
    directives: {
        screenHandle: ScreenHandleDirective
    },
    components: {
        app: { template: '<div id="main"><slot></slot></div>' }
    },
    data: {
        name: '...',
        points: [],
        scale: 1,
        rotate: 0,
        rect: {
            x: '50%',
            y: '50%',
            width: 150,
            height: 150,
            rotate: 0,
            scale: 1
        }
    },
    methods: {
        onStart (evt, info) {
            this.name = '...';
            this.points = [];
            this.points = JSON.parse(JSON.stringify(info.points));
        },
        onEnd (evt, info) {
            // console.log(info);
            let newScale = this.rect.scale * this.scale;
            this.scale = 1;
            Vue.set(this.rect, 'scale', newScale);

            let newRotate = this.rect.rotate + this.rotate;
            this.rotate = 0;
            Vue.set(this.rect, 'rotate', newRotate);
        },
        onHandle (evt, info) {
            this.name = info.name;
        },
        onMoving (evt, info) {
            this.points = JSON.parse(JSON.stringify(info.points));
        },
        onPinch (evt, info) {
            let points = info.points;
            if (points[0].target !== points[1].target) return;
            this.scale = info.scale;
        },
        onRotate (evt, info) {
            let points = info.points;
            if (points[0].target !== points[1].target) return;
            this.rotate = info.rotate;
        }
    },
    computed: {
    },
    mounted () {
        require('./index.less');
        // console.log(ScreenHandle);
    }
});

==> vuejs-2.0.11.tgz: package/src/htmls/directives/screen-handle/index.js <==
import Vue from 'vue';
import ScreenHandleDirective from '@/directives/screen-handle';
import ScreenPinchComponent from '@/components/screen/pinch';

Vue.config.productionTip = false;

/* eslint-disable no-new */
new Vue({
    el: '#app',
    directives: {
        screenHandle: ScreenHandleDirective
    },
    components: {
        app: { template: '<div id="main"><slot></slot></div>' },
        screenPinch: ScreenPinchComponent
    },
    data: {
        name: '...',
        points: [],
        scale: 1,
        rotate: 0,
        rect: {
            x: '50%',
            y: '50%',
            width: 150,
            height: 150,
            rotate: 0,
            scale: 1
        }
    },
    methods: {
        onStart (evt, info) {
            this.name = '...';
            this.points = [];
            this.points = JSON.parse(JSON.stringify(info.points));
        },
        onEnd (evt, info) {
            let newScale = this.rect.scale * this.scale;
            this.scale = 1;
            Vue.set(this.rect, 'scale', newScale);

            let newRotate = this.rect.rotate + this.rotate;
            this.rotate = 0;
            Vue.set(this.rect, 'rotate', newRotate);
        },
        onHandle (evt, info) {
            this.name = info.name;
        },
        onMoving (evt, info) {
            this.points = JSON.parse(JSON.stringify(info.points));
        },
        onPinch (evt, info) {
            let points = info.points;
            if (points[0].target !== points[1].target) return;
            this.scale = info.scale;
        },
        onRotate (evt, info) {
            let points = info.points;
            if (points[0].target !== points[1].target) return;
            this.rotate = info.rotate;
        }
    },
    computed: {
    },
    mounted () {
        require('./index.less');
        // console.log(ScreenHandle);
    }
});
